@@ -1,21 +1,20 @@
-import requests
-import threading
+import subprocess
 
 # API endpoint
 URL = "http://localhost:3774"
 
 class Watchlog:
     def send_metric(self, method, metric, value=1):
-        def make_request():
-            try:
-                if isinstance(value, (int, float, complex)):
-                    data = {'method': method, 'metric': metric, 'value': value}
-                    requests.get(url=URL, params=data)
-            except Exception as e:
-                print(f"Error in send_metric: {e}")
+        try:
+            if isinstance(value, (int, float, complex)) : 
+                params = f"method={method}&metric={metric}&value={value}"
 
-        thread = threading.Thread(target=make_request)
-        thread.start()
+                curl_command = f"curl -s -o /dev/null \"{URL}?{params}\""
+
+                subprocess.Popen(curl_command, shell=True)
+
+        except Exception as e:
+            pass
 
     def increment(self, metric, value=1):
         try:
